/*
 * talkatu
 * Copyright (C) 2017-2018 Gary Kramlich <grim@reaperworld.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GI_SCANNER__ /* hide this bit from g-ir-scanner */
#if !defined(TALKATU_GLOBAL_HEADER_INSIDE) && !defined(TALKATU_COMPILATION)
#error "only <talkatu.h> may be included directly"
#endif
#endif /* __GI_SCANNER__ */

#ifndef TALKATU_TOOL_DRAWER_H
#define TALKATU_TOOL_DRAWER_H

#include <gtk/gtk.h>

#define TALKATU_TYPE_TOOL_DRAWER            (talkatu_tool_drawer_get_type())
#define TALKATU_TOOL_DRAWER(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), TALKATU_TYPE_TOOL_DRAWER, TalkatuToolDrawer))
#define TALKATU_TOOL_DRAWER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), TALKATU_TYPE_TOOL_DRAWER, TalkatuToolDrawerClass))
#define TALKATU_IS_TOOL_DRAWER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), TALKATU_TYPE_TOOL_DRAWER))
#define TALKATU_IS_TOOL_DRAWER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), TALKATU_TYPE_TOOL_DRAWER))
#define TALKATU_TOOL_DRAWER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), TALKATU_TYPE_TOOL_DRAWER, TalkatuToolDrawerClass))

typedef struct _TalkatuToolDrawer           TalkatuToolDrawer;
typedef struct _TalkatuToolDrawerPrivate    TalkatuToolDrawerPrivate;
typedef struct _TalkatuToolDrawerClass      TalkatuToolDrawerClass;

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

struct _TalkatuToolDrawer {
	GtkToolItem parent;

	/*< private >*/
	void (*_talkatu_reserved1)(void);
	void (*_talkatu_reserved2)(void);
	void (*_talkatu_reserved3)(void);
	void (*_talkatu_reserved4)(void);
};

struct _TalkatuToolDrawerClass {
	GtkToolItemClass parent;

	/*< private >*/
	void (*_talkatu_reserved1)(void);
	void (*_talkatu_reserved2)(void);
	void (*_talkatu_reserved3)(void);
	void (*_talkatu_reserved4)(void);
};

G_BEGIN_DECLS

GType talkatu_tool_drawer_get_type(void);

GtkToolItem *talkatu_tool_drawer_new(const gchar *label, const gchar *icon_name);

void talkatu_tool_drawer_add_item(TalkatuToolDrawer *drawer, GAction *action, const gchar *markup, const gchar *icon_name, gchar *tooltip, GCallback callback);
void talkatu_tool_drawer_add_separator(TalkatuToolDrawer *drawer);

const gchar *talkatu_tool_drawer_get_label(TalkatuToolDrawer *drawer);
void talkatu_tool_drawer_set_label(TalkatuToolDrawer *drawer, const gchar *label);

const gchar *talkatu_tool_drawer_get_icon_name(TalkatuToolDrawer *drawer);
void talkatu_tool_drawer_set_icon_name(TalkatuToolDrawer *drawer, const gchar *icon_name);

void talkatu_tool_drawer_set_expanded(TalkatuToolDrawer *drawer, gboolean expanded);
gboolean talkatu_tool_drawer_get_expanded(TalkatuToolDrawer *drawer);

G_END_DECLS

#endif /* TALKATU_TOOL_DRAWER_H */
